@@ -9,11 +9,7 @@ require DynaLoader;
 use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK $VERSION);
 @ISA = qw(Exporter DynaLoader);
 
-$VERSION = '0.31_18';
-
-# This allows declaration       use UUID ':all';
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
+$VERSION = '0.31_19';
 
 %EXPORT_TAGS = (
     'all' => [qw(
@@ -34,7 +30,7 @@ __END__
 
 =head1 NAME
 
-UUID - DCE compatible Universally Unique Identifier library for Perl
+UUID - Universally Unique Identifier library for Perl
 
 =head1 SYNOPSIS
 
@@ -76,6 +72,10 @@ system, and unique across all systems, and are compatible with those
 created by the Open Software Foundation (OSF) Distributed Computing
 Environment (DCE) utility uuidgen.
 
+All generated UUIDs are either type 1 from B<UUID::generate_time()>, or
+type 4 from B<UUID::generate_random()>. And all are variant 1, meaning
+compliant with current OSF DCE standard.
+
 =head1 FUNCTIONS
 
 Most of the UUID functions expose the underlying I<libuuid> C interface
@@ -219,13 +219,9 @@ Known variants:
 
 =head1 UUID LIBRARY
 
-On some systems external packages will need to be installed first.
-Notably, uuid-dev, libuuid-devel, or uuid-devel, depending on your
-platform.
-
-Some may also have more than one package available. It should be safe to
-install all variations. The UUID installer will then opt towards the
-older, faster library.
+Prior to version 0.32, UUID required libuuid or similar be installed
+first. This is no longer the case. UUID now builds against a private
+copy of the e2fsprogs UUID code.
 
 =head1 EXPORTS
 
