@@ -7,6 +7,7 @@
 
 use strict;
 use warnings;
+use Config;
 use Devel::CheckLib;
 
 my ($out, $flagfile) = @ARGV;
@@ -51,6 +52,7 @@ sub generate_conf {
             HAVE_SYS_UN_H        sys/un.h
             HAVE_SYS_WAIT_H      sys/wait.h
             HAVE_UNISTD_H        unistd.h
+            HAVE_WINDOWS_H       Windows.h
         ));
 
         try_getdtablesize  ($check, \$longest, $defines);
@@ -63,8 +65,9 @@ sub generate_conf {
 
         try_sa_len         ($check, \$longest, $defines);
 
-        # this must come after HAVE_SYS_TIME_H check
-        try_struct_timeval ($check, \$longest, $defines);
+        # win32 native if on windows but not under some
+        # sort of unix environ. i.e. native.
+        try_win32_native   ($check, \$longest, $defines);
     }
 #
 # these havent been handled yet. do they need to be?
@@ -320,38 +323,25 @@ sub try_sa_len {
     }
 }
 
-sub try_struct_timeval {
+sub try_win32_native {
     my ($check, $long, $defs) = @_;
-    my $msg = join ' ', 'Checking struct timeval';
+    my $msg = join ' ', 'Checking win32 native';
     my $len = length $msg;
     if ($check) { $$long = $len if $len > $$long; return; }
     my $more = $$long - $len;
 
-    my $iswin = $^O eq 'MSWin32'; # need Cygwin too?
-    my $havesystimeh = grep {/define HAVE_SYS_TIME_H/} @$defs;
+    my $iswin32   = $^O eq 'MSWin32'; # need Cygwin too?
+    my $iswindows = grep {/define HAVE_WINDOWS_H/} @$defs;
+    my $isnmake   = $Config{make} eq 'nmake';
 
-    if ( check_lib(
-        header   => [
-            (( !$iswin || $havesystimeh )
-                ? 'sys/time.h'
-                : ()
-            ),
-            'time.h'
-        ],
-        #lib      => 'c', # wont link against libc
-        debug    => 0,
-        function => q{
-            struct timeval tv;
-            tv.tv_sec  = 0;
-            tv.tv_usec = 0;
-            return 0;
-        },
-    )) {
-        # do nothing. we found it.
+    if (
+        $iswin32 and $iswindows and $isnmake
+    ) {
+        push @$defs, '#define USE_WIN32_NATIVE 1';
         print $msg, ' ..', '.'x$more, ' found';
     }
     else {
-        push @$defs, 'struct timeval { long tv_sec; long tv_usec; };';
+        push @$defs, '#undef USE_WIN32_NATIVE';
         print $msg, ' ..', '.'x$more, ' missing';
     }
 }
